from plug_email_chase import utils

__docformat__ = "restructuredtext"

__version__ = "1.0.1"

# module level doc-string
__doc__ = """
plug_email_chase - a Python data pipeline for Chase Bank data from email
========================================================================

**plug_email_chase** is a Python package providing a data pipeline for Chase Bank data
pulled from the email

Main Features
-------------
Here are just a few of the things that plug_email_chase does well:

"""

if __name__ == "__main__":
    import doctest

    doctest.testmod()
